arc_user_self: Discover Authenticated User Metadata

View source: R/user-self.R

arc_user_selfR Documentation

Discover Authenticated User Metadata

Description

Given an authentication token, return a list of user-specfic information such as the user ID, username, available credits, email, groups, last login date and more.

Usage

arc_user_self(
  host = arc_host(),
  token = arc_token(),
  error_call = rlang::caller_call()
)

Arguments

host

default "https://www.arcgis.com". The host of your ArcGIS Portal.

token

an httr2_token as created by auth_code() or similar

error_call

the caller environment to be used when propagating errors.

Value

a list of the authenticated user's metadata

References

API Reference

Examples

## Not run: 
if (interactive()) {
  arc_user_self(token = auth_user())
}

## End(Not run)

arcgisutils documentation built on March 4, 2026, 9:06 a.m.