| content | R Documentation |
For a given user or group, returns a data.frame of all content items owned by them.
arc_group_content(group, host = arc_host(), token = arc_token())
arc_user_content(user, host = arc_host(), token = arc_token())
group |
a scalar character of the group ID or a |
host |
default |
token |
an |
user |
a scalar character of the username or a |
a data.frame of content item metadata
## Not run:
library(arcgis)
# authenticate
set_arc_token(auth_user())
# get your own content items
self <- arc_user_self()
arc_user_content(self$username)
# get a specific group's items
arc_group_content("2f0ec8cb03574128bd673cefab106f39")
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.