| portal_types | R Documentation |
Every portal item has an associated item type. Each of those item types have keywords which cna be used to help narrow down search further.
item_type(item_type = character(0))
item_keyword(keyword = character(0))
portal_item_keywords()
portal_item_types()
item_type |
a scalar character of the item type. See |
keyword |
a scalar character of the item type keyword. See |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.