If all items in the list are data.frames, then the result will be a data.frame.
If all elements are an sf object, then the result will be an sf object.
If the items are mixed, the result will be a data.frame.
If any items are NULL, then an attribute null_elements will be attached
to the result. The attribute is an integer vector of the indices that
were NULL.