| arc_form_params | R Documentation |
ArcGIS endpoints make extensive use of form encoded data for the body of http requests. Form requests require that each element has a name and is encoded as a single string—often as json.
arc_form_params(params = list())
as_form_params(x)
params |
a named list with scalar character elements |
x |
for |
The arc_form_params class provides validation of form body parameters
ensuring that each element is a scalar string. It uses a named list
internally to store the parameters.
The helper function as_form_params() converts a named list to form
parameters by automatically JSON-encoding each element using
yyjsonr::write_json_str() with auto_unbox = TRUE.
an object of class arc_form_params
Other geoprocessing:
arc_gp_job,
arc_job_status(),
gp_job_from_url(),
gp_params
Other geoprocessing:
arc_gp_job,
arc_job_status(),
gp_job_from_url(),
gp_params
arc_form_params(
list(f = "json", outFields = "*", where = "1 = 1")
)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.