arc_item_data: Download an Item's Data

View source: R/sharing.R

arc_item_dataR Documentation

Download an Item's Data

Description

Download the data backing a portal item. This function always returns a raw vector as the type of the data that is downloaded cannot always be known.

Usage

arc_item_data(item, host = arc_host(), token = arc_token())

Arguments

item

the item ID or the result of arc_item().

host

default "https://www.arcgis.com". The host of your ArcGIS Portal.

token

an httr2_token as created by auth_code() or similar

Details

[Experimental]

Value

a raw vector containing the bytes of the data associated with the item. If the response is application/json then the json string is returned without parsing.

See Also

Other portal item: arc_item()

Examples


arc_item_data("9df5e769bfe8412b8de36a2e618c7672")


arcgisutils documentation built on March 4, 2026, 9:06 a.m.