| arc_item_data | R Documentation |
Download the data backing a portal item. This function always returns a raw vector as the type of the data that is downloaded cannot always be known.
arc_item_data(item, host = arc_host(), token = arc_token())
item |
the item ID or the result of |
host |
default |
token |
an |
a raw vector containing the bytes of the data associated with the item. If the response is application/json then the json string is returned without parsing.
Other portal item:
arc_item()
arc_item_data("9df5e769bfe8412b8de36a2e618c7672")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.