| arc_user_self | R Documentation |
Given an authentication token, return a list of user-specfic information such as the user ID, username, available credits, email, groups, last login date and more.
arc_user_self(
host = arc_host(),
token = arc_token(),
error_call = rlang::caller_call()
)
host |
default |
token |
an |
error_call |
the caller environment to be used when propagating errors. |
a list of the authenticated user's metadata
## Not run:
if (interactive()) {
arc_user_self(token = auth_user())
}
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.